==> tiktok_business_api_sdk_official-1.0.5.tar.gz: tiktok_business_api_sdk_official-1.0.5/business_api_client/__init__.py <==
# coding: utf-8

# flake8: noqa

"""
 Copyright 2023 TikTok Pte. Ltd.

 This source code is licensed under the MIT license found in
 the LICENSE file in the root directory of this source tree.
"""
from __future__ import absolute_import

# import apis into sdk package
from business_api_client.api.account_api import AccountApi
from business_api_client.api.ad_api import AdApi
from business_api_client.api.ad_aco_api import AdAcoApi
from business_api_client.api.adgroup_api import AdgroupApi
from business_api_client.api.audience_api import AudienceApi
from business_api_client.api.authentication_api import AuthenticationApi
from business_api_client.api.bc_api import BCApi
from business_api_client.api.campaign_creation_api import CampaignCreationApi
from business_api_client.api.creative_asset_api import CreativeAssetApi
from business_api_client.api.event_callback_api import EventCallbackApi
from business_api_client.api.file_api import FileApi
from business_api_client.api.identity_api import IdentityApi
from business_api_client.api.measurement_api import MeasurementApi
from business_api_client.api.recommend_tool_api import RecommendToolApi
from business_api_client.api.reporting_api import ReportingApi
from business_api_client.api.tool_api import ToolApi
from business_api_client.api.catalog_api import CatalogApi
# import ApiClient
from business_api_client.api_client import ApiClient
from business_api_client.configuration import Configuration
# import models into sdk package
from business_api_client.models.ad_aco_body import AdAcoBody
from business_api_client.models.ad_aco_body_avatar_icon import AdAcoBodyAvatarIcon
from business_api_client.models.ad_aco_body_avatar_icon_list import AdAcoBodyAvatarIconList
from business_api_client.models.ad_aco_body_call_to_action_list import AdAcoBodyCallToActionList
from business_api_client.models.ad_aco_body_card_list import AdAcoBodyCardList
from business_api_client.models.ad_aco_body_common_material import AdAcoBodyCommonMaterial
from business_api_client.models.ad_aco_body_common_material_tracking_info import AdAcoBodyCommonMaterialTrackingInfo
from business_api_client.models.ad_aco_body_deeplink_list import AdAcoBodyDeeplinkList
from business_api_client.models.ad_aco_body_display_name_list import AdAcoBodyDisplayNameList
from business_api_client.models.ad_aco_body_landing_page_urls import AdAcoBodyLandingPageUrls
from business_api_client.models.ad_aco_body_media_info import AdAcoBodyMediaInfo
from business_api_client.models.ad_aco_body_media_info_image_info import AdAcoBodyMediaInfoImageInfo
from business_api_client.models.ad_aco_body_media_info_list import AdAcoBodyMediaInfoList
from business_api_client.models.ad_aco_body_media_info_video_info import AdAcoBodyMediaInfoVideoInfo
from business_api_client.models.ad_aco_body_page_list import AdAcoBodyPageList
from business_api_client.models.ad_aco_body_title_list import AdAcoBodyTitleList
from business_api_client.models.ad_aco_update_body import AdAcoUpdateBody
from business_api_client.models.ad_create_body import AdCreateBody
from business_api_client.models.ad_status_update_body import AdStatusUpdateBody
from business_api_client.models.ad_update_body import AdUpdateBody
from business_api_client.models.ad_upload_body import AdUploadBody
from business_api_client.models.adcreate_creatives import AdcreateCreatives
from business_api_client.models.adcreate_disclaimer_clickable_texts import AdcreateDisclaimerClickableTexts
from business_api_client.models.adcreate_disclaimer_text import AdcreateDisclaimerText
from business_api_client.models.adgroup_create_body import AdgroupCreateBody
from business_api_client.models.adgroup_status_update_body import AdgroupStatusUpdateBody
from business_api_client.models.adgroup_update_body import AdgroupUpdateBody
from business_api_client.models.adgroupcreate_actions import AdgroupcreateActions
from business_api_client.models.adgroupcreate_audience_rule import AdgroupcreateAudienceRule
from business_api_client.models.adgroupcreate_audience_rule_exclusions import AdgroupcreateAudienceRuleExclusions
from business_api_client.models.adgroupcreate_audience_rule_exclusions_event_sources import AdgroupcreateAudienceRuleExclusionsEventSources
from business_api_client.models.adgroupcreate_audience_rule_exclusions_filter import AdgroupcreateAudienceRuleExclusionsFilter
from business_api_client.models.adgroupcreate_audience_rule_exclusions_filter_filters import AdgroupcreateAudienceRuleExclusionsFilterFilters
from business_api_client.models.adgroupcreate_audience_rule_exclusions_rules import AdgroupcreateAudienceRuleExclusionsRules
from business_api_client.models.adgroupcreate_audience_rule_inclusions import AdgroupcreateAudienceRuleInclusions
from business_api_client.models.adgroupcreate_excluded_custom_actions import AdgroupcreateExcludedCustomActions
from business_api_client.models.adgroupcreate_included_custom_actions import AdgroupcreateIncludedCustomActions
from business_api_client.models.adgroupcreate_targeting_expansion import AdgroupcreateTargetingExpansion
from business_api_client.models.admin_delete_body import AdminDeleteBody
from business_api_client.models.adupdate_creatives import AdupdateCreatives
from business_api_client.models.advertiser_create_body import AdvertiserCreateBody
from business_api_client.models.advertiser_update_body import AdvertiserUpdateBody
from business_api_client.models.advertiserupdate_qualification_images import AdvertiserupdateQualificationImages
from business_api_client.models.asset_assign_body import AssetAssignBody
from business_api_client.models.asset_delete_body import AssetDeleteBody
from business_api_client.models.asset_group_create_body import AssetGroupCreateBody
from business_api_client.models.asset_group_delete_body import AssetGroupDeleteBody
from business_api_client.models.asset_group_update_body import AssetGroupUpdateBody
from business_api_client.models.asset_unassign_body import AssetUnassignBody
from business_api_client.models.bc_transfer_body import BcTransferBody
from business_api_client.models.bcadvertisercreate_advertiser_info import BcadvertisercreateAdvertiserInfo
from business_api_client.models.bcadvertisercreate_billing_group_info import BcadvertisercreateBillingGroupInfo
from business_api_client.models.bcadvertisercreate_billing_info import BcadvertisercreateBillingInfo
from business_api_client.models.bcadvertisercreate_contact_info import BcadvertisercreateContactInfo
from business_api_client.models.bcadvertisercreate_customer_info import BcadvertisercreateCustomerInfo
from business_api_client.models.bcadvertisercreate_qualification_info import BcadvertisercreateQualificationInfo
from business_api_client.models.bcasset_groupcreate_assets import BcassetGroupcreateAssets
from business_api_client.models.bcasset_groupcreate_members import BcassetGroupcreateMembers
from business_api_client.models.bcmemberinvite_ext_user_role import BcmemberinviteExtUserRole
from business_api_client.models.bid_recommend_body import BidRecommendBody
from business_api_client.models.billing_group_create_body import BillingGroupCreateBody
from business_api_client.models.billing_group_update_body import BillingGroupUpdateBody
from business_api_client.models.campaign_create_body import CampaignCreateBody
from business_api_client.models.campaign_status_update_body import CampaignStatusUpdateBody
from business_api_client.models.campaign_update_body import CampaignUpdateBody
from business_api_client.models.catalog_capitalize_body import CatalogCapitalizeBody
from business_api_client.models.catalog_create_body import CatalogCreateBody
from business_api_client.models.catalog_delete_body import CatalogDeleteBody
from business_api_client.models.catalog_update_body import CatalogUpdateBody
from business_api_client.models.catalogcreate_catalog_conf import CatalogcreateCatalogConf
from business_api_client.models.creativeportfoliocreate_advanced_audio_info import CreativeportfoliocreateAdvancedAudioInfo
from business_api_client.models.creativeportfoliocreate_advanced_gesture_icon import CreativeportfoliocreateAdvancedGestureIcon
from business_api_client.models.creativeportfoliocreate_badge_image_info import CreativeportfoliocreateBadgeImageInfo
from business_api_client.models.creativeportfoliocreate_badge_position import CreativeportfoliocreateBadgePosition
from business_api_client.models.creativeportfoliocreate_portfolio_content import CreativeportfoliocreatePortfolioContent
from business_api_client.models.creativeportfoliocreate_sticker_param import CreativeportfoliocreateStickerParam
from business_api_client.models.custom_audience_apply_body import CustomAudienceApplyBody
from business_api_client.models.custom_audience_create_body import CustomAudienceCreateBody
from business_api_client.models.custom_audience_delete_body import CustomAudienceDeleteBody
from business_api_client.models.custom_audience_share_body import CustomAudienceShareBody
from business_api_client.models.custom_audience_update_body import CustomAudienceUpdateBody
from business_api_client.models.dmpcustom_audienceapply_context_info import DmpcustomAudienceapplyContextInfo
from business_api_client.models.dmpcustom_audiencefileupload_context_info import DmpcustomAudiencefileuploadContextInfo
from business_api_client.models.dmpcustom_audiencelookalikecreate_context_info import DmpcustomAudiencelookalikecreateContextInfo
from business_api_client.models.dmpcustom_audiencelookalikecreate_lookalike_spec import DmpcustomAudiencelookalikecreateLookalikeSpec
from business_api_client.models.dmpcustom_audiencerulecreate_rule_spec import DmpcustomAudiencerulecreateRuleSpec
from business_api_client.models.dmpcustom_audiencerulecreate_rule_spec_exclusion_rule_set import DmpcustomAudiencerulecreateRuleSpecExclusionRuleSet
from business_api_client.models.dmpcustom_audiencerulecreate_rule_spec_exclusion_rule_set_filter_set import DmpcustomAudiencerulecreateRuleSpecExclusionRuleSetFilterSet
from business_api_client.models.dmpcustom_audiencerulecreate_rule_spec_exclusion_rule_set_filter_set_filters import DmpcustomAudiencerulecreateRuleSpecExclusionRuleSetFilterSetFilters
from business_api_client.models.dmpcustom_audiencerulecreate_rule_spec_exclusion_rule_set_filter_set_parameter_filters import DmpcustomAudiencerulecreateRuleSpecExclusionRuleSetFilterSetParameterFilters
from business_api_client.models.dmpcustom_audiencerulecreate_rule_spec_exclusion_rule_set_rules import DmpcustomAudiencerulecreateRuleSpecExclusionRuleSetRules
from business_api_client.models.dmpcustom_audiencerulecreate_rule_spec_inclusion_rule_set import DmpcustomAudiencerulecreateRuleSpecInclusionRuleSet
from business_api_client.models.dmpcustom_audiencerulecreate_rule_spec_inclusion_rule_set_filter_set import DmpcustomAudiencerulecreateRuleSpecInclusionRuleSetFilterSet
from business_api_client.models.dmpcustom_audiencerulecreate_rule_spec_inclusion_rule_set_filter_set_filters import DmpcustomAudiencerulecreateRuleSpecInclusionRuleSetFilterSetFilters
from business_api_client.models.dmpcustom_audiencerulecreate_rule_spec_inclusion_rule_set_filter_set_parameter_filters import DmpcustomAudiencerulecreateRuleSpecInclusionRuleSetFilterSetParameterFilters
from business_api_client.models.dmpcustom_audiencerulecreate_rule_spec_inclusion_rule_set_rules import DmpcustomAudiencerulecreateRuleSpecInclusionRuleSetRules
from business_api_client.models.dmpsaved_audiencecreate_actions import DmpsavedAudiencecreateActions
from business_api_client.models.eventsource_bind_body import EventsourceBindBody
from business_api_client.models.eventsource_unbind_body import EventsourceUnbindBody
from business_api_client.models.feed_delete_body import FeedDeleteBody
from business_api_client.models.file_image_ad_upload import FileImageAdUpload
from business_api_client.models.file_upload_body import FileUploadBody
from business_api_client.models.filtering_ad_get import FilteringAdGet
from business_api_client.models.filtering_adgroup_get import FilteringAdgroupGet
from business_api_client.models.filtering_advertiser_balance_get import FilteringAdvertiserBalanceGet
from business_api_client.models.filtering_advertiser_transaction_get import FilteringAdvertiserTransactionGet
from business_api_client.models.filtering_bc_account_transaction_get import FilteringBcAccountTransactionGet
from business_api_client.models.filtering_bc_asset_admin_get import FilteringBcAssetAdminGet
from business_api_client.models.filtering_bc_asset_get import FilteringBcAssetGet
from business_api_client.models.filtering_bc_asset_group_get import FilteringBcAssetGroupGet
from business_api_client.models.filtering_bc_asset_group_list import FilteringBcAssetGroupList
from business_api_client.models.filtering_bc_asset_member_get import FilteringBcAssetMemberGet
from business_api_client.models.filtering_bc_billing_group_get import FilteringBcBillingGroupGet
from business_api_client.models.filtering_bc_get import FilteringBcGet
from business_api_client.models.filtering_bc_member_get import FilteringBcMemberGet
from business_api_client.models.filtering_bc_partner_asset_get import FilteringBcPartnerAssetGet
from business_api_client.models.filtering_bc_partner_get import FilteringBcPartnerGet
from business_api_client.models.filtering_bc_transaction_get import FilteringBcTransactionGet
from business_api_client.models.filtering_campaign_get import FilteringCampaignGet
from business_api_client.models.filtering_report_integrated_get import FilteringReportIntegratedGet
from business_api_client.models.filtering_video_ad_search import FilteringVideoAdSearch
from business_api_client.models.identity_create_body import IdentityCreateBody
from business_api_client.models.image_upload_body import ImageUploadBody
from business_api_client.models.inline_response200 import InlineResponse200
from business_api_client.models.link_update_body import LinkUpdateBody
from business_api_client.models.lookalike_create_body import LookalikeCreateBody
from business_api_client.models.lookalike_update_body import LookalikeUpdateBody
from business_api_client.models.material_status_update_body import MaterialStatusUpdateBody
from business_api_client.models.member_delete_body import MemberDeleteBody
from business_api_client.models.member_invite_body import MemberInviteBody
from business_api_client.models.member_update_body import MemberUpdateBody
from business_api_client.models.oauth2_access_token_body import Oauth2AccessTokenBody
from business_api_client.models.partner_add_body import PartnerAddBody
from business_api_client.models.partner_delete_body import PartnerDeleteBody
from business_api_client.models.pixel_batch_body import PixelBatchBody
from business_api_client.models.pixel_content import PixelContent
from business_api_client.models.pixel_context import PixelContext
from business_api_client.models.pixel_context_ad import PixelContextAd
from business_api_client.models.pixel_context_page import PixelContextPage
from business_api_client.models.pixel_context_user import PixelContextUser
from business_api_client.models.pixel_properties import PixelProperties
from business_api_client.models.pixel_track_body import PixelTrackBody
from business_api_client.models.pixel_transfer_body import PixelTransferBody
from business_api_client.models.pixelbatch_batch import PixelbatchBatch
from business_api_client.models.portfolio_create_body import PortfolioCreateBody
from business_api_client.models.product_delete_body import ProductDeleteBody
from business_api_client.models.product_file_body import ProductFileBody
from business_api_client.models.rule_create_body import RuleCreateBody
from business_api_client.models.saved_audience_create_body import SavedAudienceCreateBody
from business_api_client.models.saved_audience_delete_body import SavedAudienceDeleteBody
from business_api_client.models.share_cancel_body import ShareCancelBody
from business_api_client.models.targeting_category_recommend_body import TargetingCategoryRecommendBody
from business_api_client.models.targeting_info_body import TargetingInfoBody
from business_api_client.models.targeting_search_body import TargetingSearchBody
# import customized class into sdk package
from business_api_client.tiktok_business.tiktok_code import *
from business_api_client.tiktok_business.tiktok_exceptions import *
from business_api_client.tiktok_business.tiktok_response import *
from business_api_client.tiktok_business.tiktok_utils import *

# sdk current version
__version__ = '0.1.4'

==> tiktok_business_api_sdk_official-1.0.7.tar.gz: tiktok_business_api_sdk_official-1.0.7/business_api_client/__init__.py <==
# coding: utf-8

# flake8: noqa

"""
 Copyright 2023 TikTok Pte. Ltd.

 This source code is licensed under the MIT license found in
 the LICENSE file in the root directory of this source tree.
"""
from __future__ import absolute_import

# import apis into sdk package
from business_api_client.api.app_management_api import APPManagementApi
from business_api_client.api.account_management_api import AccountManagementApi
from business_api_client.api.ad_api import AdApi
from business_api_client.api.ad_aco_api import AdAcoApi
from business_api_client.api.adgroup_api import AdgroupApi
from business_api_client.api.audience_api import AudienceApi
from business_api_client.api.authentication_api import AuthenticationApi
from business_api_client.api.bc_api import BCApi
from business_api_client.api.campaign_creation_api import CampaignCreationApi
from business_api_client.api.creative_asset_api import CreativeAssetApi
from business_api_client.api.event_callback_api import EventCallbackApi
from business_api_client.api.file_api import FileApi
from business_api_client.api.identity_api import IdentityApi
from business_api_client.api.recommend_tool_api import RecommendToolApi
from business_api_client.api.reporting_api import ReportingApi
from business_api_client.api.tool_api import ToolApi
from business_api_client.api.catalog_api import CatalogApi
# import ApiClient
from business_api_client.api_client import ApiClient
from business_api_client.configuration import Configuration
# import models into sdk package
from business_api_client.models.ad_aco_body import AdAcoBody
from business_api_client.models.ad_aco_body_avatar_icon import AdAcoBodyAvatarIcon
from business_api_client.models.ad_aco_body_avatar_icon_list import AdAcoBodyAvatarIconList
from business_api_client.models.ad_aco_body_call_to_action_list import AdAcoBodyCallToActionList
from business_api_client.models.ad_aco_body_card_list import AdAcoBodyCardList
from business_api_client.models.ad_aco_body_common_material import AdAcoBodyCommonMaterial
from business_api_client.models.ad_aco_body_common_material_tracking_info import AdAcoBodyCommonMaterialTrackingInfo
from business_api_client.models.ad_aco_body_deeplink_list import AdAcoBodyDeeplinkList
from business_api_client.models.ad_aco_body_display_name_list import AdAcoBodyDisplayNameList
from business_api_client.models.ad_aco_body_landing_page_urls import AdAcoBodyLandingPageUrls
from business_api_client.models.ad_aco_body_media_info import AdAcoBodyMediaInfo
from business_api_client.models.ad_aco_body_media_info_image_info import AdAcoBodyMediaInfoImageInfo
from business_api_client.models.ad_aco_body_media_info_list import AdAcoBodyMediaInfoList
from business_api_client.models.ad_aco_body_media_info_video_info import AdAcoBodyMediaInfoVideoInfo
from business_api_client.models.ad_aco_body_page_list import AdAcoBodyPageList
from business_api_client.models.ad_aco_body_title_list import AdAcoBodyTitleList
from business_api_client.models.ad_aco_update_body import AdAcoUpdateBody
from business_api_client.models.ad_create_body import AdCreateBody
from business_api_client.models.ad_status_update_body import AdStatusUpdateBody
from business_api_client.models.ad_update_body import AdUpdateBody
from business_api_client.models.ad_upload_body import AdUploadBody
from business_api_client.models.adcreate_creatives import AdcreateCreatives
from business_api_client.models.adcreate_disclaimer_clickable_texts import AdcreateDisclaimerClickableTexts
from business_api_client.models.adcreate_disclaimer_text import AdcreateDisclaimerText
from business_api_client.models.adgroup_create_body import AdgroupCreateBody
from business_api_client.models.adgroup_status_update_body import AdgroupStatusUpdateBody
from business_api_client.models.adgroup_update_body import AdgroupUpdateBody
from business_api_client.models.adgroupcreate_actions import AdgroupcreateActions
from business_api_client.models.adgroupcreate_audience_rule import AdgroupcreateAudienceRule
from business_api_client.models.adgroupcreate_audience_rule_exclusions import AdgroupcreateAudienceRuleExclusions
from business_api_client.models.adgroupcreate_audience_rule_exclusions_event_sources import AdgroupcreateAudienceRuleExclusionsEventSources
from business_api_client.models.adgroupcreate_audience_rule_exclusions_filter import AdgroupcreateAudienceRuleExclusionsFilter
from business_api_client.models.adgroupcreate_audience_rule_exclusions_filter_filters import AdgroupcreateAudienceRuleExclusionsFilterFilters
from business_api_client.models.adgroupcreate_audience_rule_exclusions_rules import AdgroupcreateAudienceRuleExclusionsRules
from business_api_client.models.adgroupcreate_audience_rule_inclusions import AdgroupcreateAudienceRuleInclusions
from business_api_client.models.adgroupcreate_excluded_custom_actions import AdgroupcreateExcludedCustomActions
from business_api_client.models.adgroupcreate_included_custom_actions import AdgroupcreateIncludedCustomActions
from business_api_client.models.adgroupcreate_targeting_expansion import AdgroupcreateTargetingExpansion
from business_api_client.models.admin_delete_body import AdminDeleteBody
from business_api_client.models.adupdate_creatives import AdupdateCreatives
from business_api_client.models.advertiser_create_body import AdvertiserCreateBody
from business_api_client.models.advertiser_update_body import AdvertiserUpdateBody
from business_api_client.models.advertiserupdate_advertiser_budgets import AdvertiserupdateAdvertiserBudgets
from business_api_client.models.advertiserupdate_qualification_images import AdvertiserupdateQualificationImages
from business_api_client.models.app_create_body import AppCreateBody
from business_api_client.models.app_update_body import AppUpdateBody
from business_api_client.models.appcreate_tracking_url import AppcreateTrackingUrl
from business_api_client.models.appupdate_tracking_url import AppupdateTrackingUrl
from business_api_client.models.asset_assign_body import AssetAssignBody
from business_api_client.models.asset_delete_body import AssetDeleteBody
from business_api_client.models.asset_group_create_body import AssetGroupCreateBody
from business_api_client.models.asset_group_delete_body import AssetGroupDeleteBody
from business_api_client.models.asset_group_update_body import AssetGroupUpdateBody
from business_api_client.models.asset_unassign_body import AssetUnassignBody
from business_api_client.models.bc_transfer_body import BcTransferBody
from business_api_client.models.bcadvertisercreate_advertiser_info import BcadvertisercreateAdvertiserInfo
from business_api_client.models.bcadvertisercreate_billing_group_info import BcadvertisercreateBillingGroupInfo
from business_api_client.models.bcadvertisercreate_billing_info import BcadvertisercreateBillingInfo
from business_api_client.models.bcadvertisercreate_contact_info import BcadvertisercreateContactInfo
from business_api_client.models.bcadvertisercreate_customer_info import BcadvertisercreateCustomerInfo
from business_api_client.models.bcadvertisercreate_qualification_info import BcadvertisercreateQualificationInfo
from business_api_client.models.bcasset_groupcreate_assets import BcassetGroupcreateAssets
from business_api_client.models.bcasset_groupcreate_members import BcassetGroupcreateMembers
from business_api_client.models.bcmemberinvite_ext_user_role import BcmemberinviteExtUserRole
from business_api_client.models.bid_recommend_body import BidRecommendBody
from business_api_client.models.billing_group_create_body import BillingGroupCreateBody
from business_api_client.models.billing_group_update_body import BillingGroupUpdateBody
from business_api_client.models.campaign_create_body import CampaignCreateBody
from business_api_client.models.campaign_status_update_body import CampaignStatusUpdateBody
from business_api_client.models.campaign_update_body import CampaignUpdateBody
from business_api_client.models.catalog_capitalize_body import CatalogCapitalizeBody
from business_api_client.models.catalog_create_body import CatalogCreateBody
from business_api_client.models.catalog_delete_body import CatalogDeleteBody
from business_api_client.models.catalog_update_body import CatalogUpdateBody
from business_api_client.models.catalogcreate_catalog_conf import CatalogcreateCatalogConf
from business_api_client.models.creativeportfoliocreate_advanced_audio_info import CreativeportfoliocreateAdvancedAudioInfo
from business_api_client.models.creativeportfoliocreate_advanced_gesture_icon import CreativeportfoliocreateAdvancedGestureIcon
from business_api_client.models.creativeportfoliocreate_badge_image_info import CreativeportfoliocreateBadgeImageInfo
from business_api_client.models.creativeportfoliocreate_badge_position import CreativeportfoliocreateBadgePosition
from business_api_client.models.creativeportfoliocreate_portfolio_content import CreativeportfoliocreatePortfolioContent
from business_api_client.models.creativeportfoliocreate_sticker_param import CreativeportfoliocreateStickerParam
from business_api_client.models.custom_audience_apply_body import CustomAudienceApplyBody
from business_api_client.models.custom_audience_create_body import CustomAudienceCreateBody
from business_api_client.models.custom_audience_delete_body import CustomAudienceDeleteBody
from business_api_client.models.custom_audience_share_body import CustomAudienceShareBody
from business_api_client.models.custom_audience_update_body import CustomAudienceUpdateBody
from business_api_client.models.dmpcustom_audienceapply_context_info import DmpcustomAudienceapplyContextInfo
from business_api_client.models.dmpcustom_audiencefileupload_context_info import DmpcustomAudiencefileuploadContextInfo
from business_api_client.models.dmpcustom_audiencelookalikecreate_context_info import DmpcustomAudiencelookalikecreateContextInfo
from business_api_client.models.dmpcustom_audiencelookalikecreate_lookalike_spec import DmpcustomAudiencelookalikecreateLookalikeSpec
from business_api_client.models.dmpcustom_audiencerulecreate_rule_spec import DmpcustomAudiencerulecreateRuleSpec
from business_api_client.models.dmpcustom_audiencerulecreate_rule_spec_exclusion_rule_set import DmpcustomAudiencerulecreateRuleSpecExclusionRuleSet
from business_api_client.models.dmpcustom_audiencerulecreate_rule_spec_exclusion_rule_set_filter_set import DmpcustomAudiencerulecreateRuleSpecExclusionRuleSetFilterSet
from business_api_client.models.dmpcustom_audiencerulecreate_rule_spec_exclusion_rule_set_filter_set_filters import DmpcustomAudiencerulecreateRuleSpecExclusionRuleSetFilterSetFilters
from business_api_client.models.dmpcustom_audiencerulecreate_rule_spec_exclusion_rule_set_filter_set_parameter_filters import DmpcustomAudiencerulecreateRuleSpecExclusionRuleSetFilterSetParameterFilters
from business_api_client.models.dmpcustom_audiencerulecreate_rule_spec_exclusion_rule_set_rules import DmpcustomAudiencerulecreateRuleSpecExclusionRuleSetRules
from business_api_client.models.dmpcustom_audiencerulecreate_rule_spec_inclusion_rule_set import DmpcustomAudiencerulecreateRuleSpecInclusionRuleSet
from business_api_client.models.dmpcustom_audiencerulecreate_rule_spec_inclusion_rule_set_filter_set import DmpcustomAudiencerulecreateRuleSpecInclusionRuleSetFilterSet
from business_api_client.models.dmpcustom_audiencerulecreate_rule_spec_inclusion_rule_set_filter_set_filters import DmpcustomAudiencerulecreateRuleSpecInclusionRuleSetFilterSetFilters
from business_api_client.models.dmpcustom_audiencerulecreate_rule_spec_inclusion_rule_set_filter_set_parameter_filters import DmpcustomAudiencerulecreateRuleSpecInclusionRuleSetFilterSetParameterFilters
from business_api_client.models.dmpcustom_audiencerulecreate_rule_spec_inclusion_rule_set_rules import DmpcustomAudiencerulecreateRuleSpecInclusionRuleSetRules
from business_api_client.models.dmpsaved_audiencecreate_actions import DmpsavedAudiencecreateActions
from business_api_client.models.eventsource_bind_body import EventsourceBindBody
from business_api_client.models.eventsource_unbind_body import EventsourceUnbindBody
from business_api_client.models.feed_delete_body import FeedDeleteBody
from business_api_client.models.file_image_ad_upload import FileImageAdUpload
from business_api_client.models.file_upload_body import FileUploadBody
from business_api_client.models.filtering_ad_get import FilteringAdGet
from business_api_client.models.filtering_adgroup_get import FilteringAdgroupGet
from business_api_client.models.filtering_advertiser_balance_get import FilteringAdvertiserBalanceGet
from business_api_client.models.filtering_advertiser_transaction_get import FilteringAdvertiserTransactionGet
from business_api_client.models.filtering_bc_account_transaction_get import FilteringBcAccountTransactionGet
from business_api_client.models.filtering_bc_asset_admin_get import FilteringBcAssetAdminGet
from business_api_client.models.filtering_bc_asset_get import FilteringBcAssetGet
from business_api_client.models.filtering_bc_asset_group_get import FilteringBcAssetGroupGet
from business_api_client.models.filtering_bc_asset_group_list import FilteringBcAssetGroupList
from business_api_client.models.filtering_bc_asset_member_get import FilteringBcAssetMemberGet
from business_api_client.models.filtering_bc_billing_group_get import FilteringBcBillingGroupGet
from business_api_client.models.filtering_bc_get import FilteringBcGet
from business_api_client.models.filtering_bc_member_get import FilteringBcMemberGet
from business_api_client.models.filtering_bc_partner_asset_get import FilteringBcPartnerAssetGet
from business_api_client.models.filtering_bc_partner_get import FilteringBcPartnerGet
from business_api_client.models.filtering_bc_transaction_get import FilteringBcTransactionGet
from business_api_client.models.filtering_campaign_get import FilteringCampaignGet
from business_api_client.models.filtering_report_integrated_get import FilteringReportIntegratedGet
from business_api_client.models.filtering_video_ad_search import FilteringVideoAdSearch
from business_api_client.models.identity_create_body import IdentityCreateBody
from business_api_client.models.image_upload_body import ImageUploadBody
from business_api_client.models.inline_response200 import InlineResponse200
from business_api_client.models.link_update_body import LinkUpdateBody
from business_api_client.models.lookalike_create_body import LookalikeCreateBody
from business_api_client.models.lookalike_update_body import LookalikeUpdateBody
from business_api_client.models.material_status_update_body import MaterialStatusUpdateBody
from business_api_client.models.member_delete_body import MemberDeleteBody
from business_api_client.models.member_invite_body import MemberInviteBody
from business_api_client.models.member_update_body import MemberUpdateBody
from business_api_client.models.oauth2_access_token_body import Oauth2AccessTokenBody
from business_api_client.models.pangle_block_list_update_body import PangleBlockListUpdateBody
from business_api_client.models.partner_add_body import PartnerAddBody
from business_api_client.models.partner_delete_body import PartnerDeleteBody
from business_api_client.models.pixel_batch_body import PixelBatchBody
from business_api_client.models.pixel_content import PixelContent
from business_api_client.models.pixel_context import PixelContext
from business_api_client.models.pixel_context_ad import PixelContextAd
from business_api_client.models.pixel_context_page import PixelContextPage
from business_api_client.models.pixel_context_user import PixelContextUser
from business_api_client.models.pixel_properties import PixelProperties
from business_api_client.models.pixel_track_body import PixelTrackBody
from business_api_client.models.pixel_transfer_body import PixelTransferBody
from business_api_client.models.pixelbatch_batch import PixelbatchBatch
from business_api_client.models.portfolio_create_body import PortfolioCreateBody
from business_api_client.models.product_delete_body import ProductDeleteBody
from business_api_client.models.product_file_body import ProductFileBody
from business_api_client.models.reporttaskcreate_filtering import ReporttaskcreateFiltering
from business_api_client.models.rule_create_body import RuleCreateBody
from business_api_client.models.saved_audience_create_body import SavedAudienceCreateBody
from business_api_client.models.saved_audience_delete_body import SavedAudienceDeleteBody
from business_api_client.models.share_cancel_body import ShareCancelBody
from business_api_client.models.targeting_category_recommend_body import TargetingCategoryRecommendBody
from business_api_client.models.targeting_info_body import TargetingInfoBody
from business_api_client.models.targeting_search_body import TargetingSearchBody
from business_api_client.models.task_cancel_body import TaskCancelBody
from business_api_client.models.task_create_body import TaskCreateBody
from business_api_client.models.term_confirm_body import TermConfirmBody
# import customized class into sdk package
from business_api_client.tiktok_business.tiktok_code import *
from business_api_client.tiktok_business.tiktok_exceptions import *
from business_api_client.tiktok_business.tiktok_response import *
from business_api_client.tiktok_business.tiktok_utils import *

# sdk current version
__version__ = '0.1.5'
